edman_web
=========

|py_version|

|  KEK IMSS SBRC/PF Experimental Data Management System.
|  sub-package of edman for web applications.

Requirement
-----------
-   pymongo
-   Flask
-   and MongoDB.

Modules Usage
-------------

◯Note

::
    TODO

Install
-------

pip install::

 pip install edman_web

Licence
-------
MIT

PyPI Project
------------
https://pypi.org/project/edman_web/

API Document
------------
https://ryde.github.io/edman_web/

Author
------

[ryde](https://github.com/ryde)

[yuskyamada](https://github.com/yuskyamada)

.. |py_version| image:: https://img.shields.io/badge/python-3.11-blue.svg
    :alt: Use python
